==================================
 (one line goal description here)
==================================

Description
===========

Explain what the goal is in general terms. Include the reasoning and
justification for applying the goal to all OpenStack projects.

Design & Implementation details
===============================

Add all the details about design, implementation, direction, etc or
link where these are explained.

Goal Checklist
==============

Is design finalized? (Mandatory)
--------------------------------

Status: <YES/NO>
<Provide links to specs, gerrit, etherpad, wiki, IRC, or other documention
sites>

Is implemenation finalized? (Mandatory)
---------------------------------------

Status: <YES/NO>
<Provide link to gerrit, etherpad, wiki, ML, etc> |

Is there any dependency or blocker? (Mandatory)
-----------------------------------------------

Status: <YES/NO>
<List all dependencies or blockers from OpenStack or External software with
their plan and possibilities to complete>

Current state (Optional)
------------------------

Provide a summary of the current state of any ongoing work related to
the goal, including projects that have completed the work already and
can serve as examples.

Regular Meeting & Discussion (Optional)
---------------------------------------

<Provide links to regular meetings or discussion where projects can
contact champion for their query. If you have not planned any regular
meetings then mention "openstack-discuss ML" or IRC channel for discussion>

Completion Date & Criteria
==========================

Set the target dates or different milestones with the items that must be true
in order to call the milestone and goal "completed" for a given project.

Completion Date:
Items to complete:
#. one
#. two

OR

Milestone 1 Date:
Items to complete:
#. one
#. two

Milestone 2 Date:
Items to complete:
#. one
#. two
.
.

Champion
========

Goals need a main driver to project-manage them to completion. Project teams
need assistance, reminders and sometimes direct help in order for them to
complete the goals.

Status & Tracking
=================

:Storyboard Board: <put the link to the tracking board here>
:Storyboard Story: <put the link to the story for this goal here>
 OR
:Etherpad: <put the link to etherpad where progress is tracked>

Gerrit Topic
------------

To facilitate tracking, commits related to this goal should use the
gerrit topic::

  <insert topic here>

References
==========

Provide reference links to previous discussions on the mailing list or
IRC, etherpads, wiki pages, other forms of notes, and documentation
that would be useful to a project team in working on the goal.
